@@ -1,5 +1,5 @@
-from gssc.networks import ResSleep, SleepGRU
-from gssc.utils import make_blueprint
+from .networks import ResSleep, SleepGRU
+from .utils import make_blueprint
 import torch
 
 sigs = {"eeg":{"chans":"eeg", "perms":[0,1], "flip":True},
